==> huaweicloudsdksdrs-3.0.78-py2.py3-none-any.whl: huaweicloudsdksdrs/v1/model/list_protected_instances_by_tags_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListProtectedInstancesByTagsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'resources': 'list[ResourceParams]',
        'total_count': 'int'
    }

    attribute_map = {
        'resources': 'resources',
        'total_count': 'total_count'
    }

    def __init__(self, resources=None, total_count=None):
        """ListProtectedInstancesByTagsResponse - a model defined in huaweicloud sdk"""
        
        super(ListProtectedInstancesByTagsResponse, self).__init__()

        self._resources = None
        self._total_count = None
        self.discriminator = None

        if resources is not None:
            self.resources = resources
        if total_count is not None:
            self.total_count = total_count

    @property
    def resources(self):
        """Gets the resources of this ListProtectedInstancesByTagsResponse.

        返回的保护实例列表。

        :return: The resources of this ListProtectedInstancesByTagsResponse.
        :rtype: list[ResourceParams]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this ListProtectedInstancesByTagsResponse.

        返回的保护实例列表。

        :param resources: The resources of this ListProtectedInstancesByTagsResponse.
        :type: list[ResourceParams]
        """
        self._resources = resources

    @property
    def total_count(self):
        """Gets the total_count of this ListProtectedInstancesByTagsResponse.

        总记录数。该值不受过滤条件的影响。

        :return: The total_count of this ListProtectedInstancesByTagsResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListProtectedInstancesByTagsResponse.

        总记录数。该值不受过滤条件的影响。

        :param total_count: The total_count of this ListProtectedInstancesByTagsResponse.
        :type: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListProtectedInstancesByTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksdrs-3.0.100-py2.py3-none-any.whl: huaweicloudsdksdrs/v1/model/list_protected_instances_by_tags_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListProtectedInstancesByTagsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'resources': 'list[ResourceParams]',
        'total_count': 'int'
    }

    attribute_map = {
        'resources': 'resources',
        'total_count': 'total_count'
    }

    def __init__(self, resources=None, total_count=None):
        """ListProtectedInstancesByTagsResponse

        The model defined in huaweicloud sdk

        :param resources: 返回的保护实例列表。
        :type resources: list[:class:`huaweicloudsdksdrs.v1.ResourceParams`]
        :param total_count: 总记录数。该值不受过滤条件的影响。
        :type total_count: int
        """
        
        super(ListProtectedInstancesByTagsResponse, self).__init__()

        self._resources = None
        self._total_count = None
        self.discriminator = None

        if resources is not None:
            self.resources = resources
        if total_count is not None:
            self.total_count = total_count

    @property
    def resources(self):
        """Gets the resources of this ListProtectedInstancesByTagsResponse.

        返回的保护实例列表。

        :return: The resources of this ListProtectedInstancesByTagsResponse.
        :rtype: list[:class:`huaweicloudsdksdrs.v1.ResourceParams`]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this ListProtectedInstancesByTagsResponse.

        返回的保护实例列表。

        :param resources: The resources of this ListProtectedInstancesByTagsResponse.
        :type resources: list[:class:`huaweicloudsdksdrs.v1.ResourceParams`]
        """
        self._resources = resources

    @property
    def total_count(self):
        """Gets the total_count of this ListProtectedInstancesByTagsResponse.

        总记录数。该值不受过滤条件的影响。

        :return: The total_count of this ListProtectedInstancesByTagsResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListProtectedInstancesByTagsResponse.

        总记录数。该值不受过滤条件的影响。

        :param total_count: The total_count of this ListProtectedInstancesByTagsResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListProtectedInstancesByTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
